\name{EUt}
\alias{EUt}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Optimal cut-off estimation of a prognostic variable
}
\description{
This function allows the estimation of an optimal cut-off estimation for medical decison making from a prognostic marker by maximizing the expected utility.
}
\usage{
EUt(times, failures, variable, pro.time, cut.off, estimator, lambda = NULL,
 u.tn, u.fp, u.tp0, u.tp1, u.fn0, u.fn1, gain = 0, reference = "negative")
}
\arguments{
  \item{times}{A numeric vector with the follow up times.}
  \item{failures}{A numeric vector with the event indicator (0=right censored, 1=event).}
  \item{variable}{A numeric vector with the prognostic variable. This variable is collected at the baseline.}
  \item{pro.time}{The value of prognostic time represents the maximum delay for which the capacity of the variable is evaluated. The same unit than the one used in the argument \code{time}.}
  \item{cut.off}{The cut-off values of the variable used to define the possible binary tests.}
  \item{estimator}{Three possible estimators can be used: 'kaplan-meier', 'akritas' or 'naive'. The naive estimator is selected by default.}
  \item{lambda}{This is the proportion of the nearest neighbours. The estimation will be based on 2*lambda (1 lambda on the left and 1 lambda on the right) of the total sample size. This parameter will only be used in the k-nearest neighbour's estimation (\code{estimator='akritas'}).}
  \item{u.tn}{The value of the utility related to a patient with a true negative test. This value should respect the 0-1 scale death-perfect health.}
  \item{u.fp}{The value of the utility related to a patient with a false positive test. This value should respect the 0-1 scale death-perfect health.}
  \item{u.tp0}{The value of the utility related to a patient with a true positive test before the failure occurs. This value should respect the 0-1 scale death-perfect health.}
  \item{u.tp1}{The value of the utility related to a patient with a true positive test after the failure occurs. This value should respect the 0-1 scale death-perfect health.}
  \item{u.fn0}{The value of the utility related to a patient with a false negative test before the failure occurs. This value should respect the 0-1 scale death-perfect health.}
  \item{u.fn1}{The value of the utility related to a patient with a false negative test after the failure occurs. This value should respect the 0-1 scale death-perfect health.}
  \item{gain}{A numeric vector with the expected percentages in the increase of the mean time-to-failure due to the novel therapy. The default value is 0. These values have to be between 0 and 100. The size of the vector have to be the same than the one of the argument "cut.off". It allows the possibility to consider a dependence between the cut-off value and the gain.}
  \item{reference}{The possible options are "negative" or "positive". That indicates the group of patients maintained with the reference (standard) care. For instance if "negative", patients with a negative test will received the reference care, while patients with a positive test will receive the novel therapy. The default value is "negative".}
}
\details{
This function computes the expected utility function for the cut-off defined by the user. The individual data may be right-censored. It can use Akritas approach (nearest neighbour's estimation) for ensuring monotone property of the corresponding function, instead of the simple Kaplan-Meier estimator. This Akritas approach may be avoid if the sample size is large because of computing time. Both estimators were defined by Heagerty, Lumley and Pepe (Biometrics, 2000). A third alternative is the use of the naive estimator as explained by Blanche, Dartigues and Jacqmin-Gadda (2013). This estimator is less time-consuming compared to the Akritas approach.  The user have to define the utilities/qualities of life related to the possible health-states of the patients after the prognostic marker-based decision. A positive test is defined by a marker value higher than the cut-off: the patient is considered at risk of the failure before the prognostic time. The situation consists in the prescription of a novel therapy to avoid/delay the failure in high-risk patients, but with a decrease in the quality of life versus non-treated patients. For true positive and false negative test, we distinguish the quality of life before and after the failure, the quality of life being higher before than after. 
}
\value{
\item{missing}{Number of deleted observations due to missing data.}
\item{proba.table}{This data frame is composed by 4 columns representing respectively the probabilities of true positive test (tp), false positive test (fp), true negative test (tn) and false negative test (fp). Each line corresponds to the cut-off values entered by the user.}
\item{qaly.table}{This data frame is composed by 4 columns representing respectively the QALYs of true positive test (tp), false positive test (fp), true negative test (tn) and false negative test (fp).  Each line corresponds to the cut-off values entered by the user.}
\item{eu.table}{This data frame returns the expected utilities associated with the cut-off values entered by the user.}
\item{eu.all}{The expected utility if all patients are treated (the cut-off is the minimum of the prognostic variable).}
\item{eu.no}{The expected utility if no patient is treated (the cut-off is the maximum of the prognostic variable).}
\item{results}{This vector contains three values. The first one is (estimation) is the cut-off that maximizes the expected utility of the medical decision. If this value corresponds to the minimum or the maximum of the prognostic variable, all the patients or no patient should respectively be treated. The second one (eu) corresponds to the maximum expected utility associated with the previous cut-off value. The third one (gain)  corresponds to the gain entered by the user for this estimated cut-off.}
}
\references{
Foucher et al. (2010) A clinical scoring system highly predictive of long-term kidney graft survival. Kidney International, 78:1288-94. 

Tessier P et al. Manuscript submitted.
}
\author{
Y. Foucher <Yohann.Foucher@univ-nantes.fr>
}
%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
\examples{

# import and attach the data example

data(dataKTFS)

# cut-off values definition (choose more values in practice)

ktfs.cut <- quantile(dataKTFS$score, probs=seq(0.1, 0.9, by=0.1), na.rm=TRUE)

# the corresponding expected utility function for a prognostic
# up to 8 years post-transplantation

estim.naive <- EUt(dataKTFS$time, dataKTFS$failure, dataKTFS$score,
 pro.time=8, cut.off=ktfs.cut, estimator="naive", lambda=NULL, u.tn=0.81,
 u.fp=0.81*0.99, u.tp0=0.81*0.99, u.tp1=0.53, u.fn0=0.81, u.fn1=0.53,
 gain=0.5)

plot(estim.naive$eu.table$cut.off, estim.naive$eu.table$utility, type="l",
 xlab="Cut-off values", ylab="Expected utility", col=1, lty=1)

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ Utility }
\keyword{ Cut-off }
\keyword{ Time-dependent }
